bayespy.inference.vmp.nodes.bernoulli.BernoulliDistribution.__init__
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliDistribution.__init__